@@ -3,13 +3,12 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0200';
 
 use Data::Dumper::Compact qw(ddc);
 use Graph::Directed;
 use Music::Scales qw(get_scale_notes);
 use Music::Chord::Note;
-
 use Moo;
 use strictures 2;
 use namespace::clean;
@@ -85,6 +84,13 @@ has substitute => (
 );
 
 
+has sub_cond => (
+    is      => 'ro',
+    isa     => sub { die "$_[0] is not a valid coderef" unless ref($_[0]) eq 'CODE' },
+    default => sub { return sub { int rand 4 == 0 } },
+);
+
+
 has flat => (
     is      => 'ro',
     isa     => sub { die "$_[0] is not a valid boolean" unless $_[0] =~ /^[01]$/ },
@@ -123,27 +129,24 @@ sub generate {
     for my $n (1 .. $self->max) {
         if ($n == 1) {
             if ($self->tonic == 0) {
-                $v = (@{ $self->net->{1} })[int rand @{ $self->net->{1} }];
+                $v = $self->graph->random_successor(1);
             }
             elsif ($self->tonic == 1) {
                 $v = 1;
             }
             else {
-                my @keys = grep { keys @{ $self->net->{$_} } > 0 } keys %{ $self->net };
-                $v = $keys[int rand @keys];
+                $v = $self->_full_keys;
             }
         }
         elsif ($n == $self->max) {
             if ($self->resolve == 0) {
-                my @keys = keys %{ $self->net };
-                $v = (@{ $self->net->{ scalar @keys } })[int rand @{ $self->net->{ scalar @keys } }];
+                $v = $self->graph->random_successor(scalar keys %{ $self->net });
             }
             elsif ($self->resolve == 1) {
                 $v = 1;
             }
             else {
-                my @keys = grep { keys @{ $self->net->{$_} } > 0 } keys %{ $self->net };
-                $v = $keys[int rand @keys];
+                $v = $self->_full_keys;
             }
         }
         else {
@@ -158,12 +161,20 @@ sub generate {
     my $chords = $self->chords;
 
     if ($self->substitute) {
+        my $i = 0;
         for my $chord (@$chords) {
-            $chord = int rand 2 ? $self->substitution($chord) : $chord;
+            my $substitute = $self->sub_cond->() ? $self->substitution($chord) : $chord;
+            if ($substitute eq $chord) {
+                if ($self->sub_cond->()) {
+                    $progression[$i] .= 't';
+                }
+            }
+            $chord = $substitute;
+            $i++;
         }
     }
 
-    my @phrase = map { $scale[$_ - 1] . $chords->[$_ - 1] } @progression;
+    my @phrase = map { $self->_tt_sub(\@scale, $chords, $_) } @progression;
     print "Phrase: @phrase\n" if $self->verbose;
 
     # Add octaves to the chord notes
@@ -194,6 +205,43 @@ sub generate {
     return \@notes;
 }
 
+sub _full_keys {
+    my ($self) = @_;
+    my @keys = grep { keys @{ $self->net->{$_} } > 0 } keys %{ $self->net };
+    return $keys[int rand @keys];
+}
+
+sub _tt_sub {
+    my ($self, $scale, $chords, $n) = @_;
+
+    my %tritone = (
+        'C'  => 'F#',
+        'C#' => 'G',
+        'D'  => 'G#',
+        'D#' => 'A',
+        'E'  => 'A#',
+        'F'  => 'B',
+        'F#' => 'C',
+        'G'  => 'C#',
+        'G#' => 'D',
+        'A'  => 'D#',
+        'A#' => 'E',
+        'B'  => 'F',
+    );
+
+    my $note;
+    if ($n =~ /t/) {
+        $n =~ s/t//;
+        $note = $tritone{ $scale->[$n - 1] };
+        print "TT: $scale->[$n - 1] => $note\n" if $self->verbose;
+    }
+    else {
+        $note = $scale->[$n - 1];
+    }
+
+    return $note . $chords->[$n - 1];
+}
+
 
 # These gymnastics are performed to appease Music::Chord::Note
 sub substitution {
@@ -242,7 +290,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0100
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -366,6 +414,13 @@ Whether to perform jazz chord substitution.
 
 Default: C<0>
 
+=head2 sub_cond
+
+The subroutine to execute to determine if a chord substitution should
+happen.
+
+Default: C<sub { int rand 4 == 0 }>
+
 =head2 flat
 
 Whether to use flats instead of sharps in the chords or not.
@@ -421,7 +476,7 @@ Rules:
 
   * Any dominant chord can be changed to a 9, 11, or 13
 
-  * Any chord can be changed to a chord a tritone away (not implemented)
+  * Any chord can be changed to a chord a tritone away
 
 =head1 SEE ALSO
 
